Loosen up sys_time.gettimeofday.

We've seen it take 1146us on Nexus 9 (which did have exceptionally slow
system calls).

Bug: http://b/26724042
Change-Id: I263b7e1267d58fe4a6528403d03e5b245fdcd528
diff --git a/tests/sys_time_test.cpp b/tests/sys_time_test.cpp
index bb142bc..18fbe10 100644
--- a/tests/sys_time_test.cpp
+++ b/tests/sys_time_test.cpp
@@ -63,7 +63,7 @@
     tv2.tv_usec += 1000000;
   }
 
   // Should be less than (a very generous, to try to avoid flakiness) 1000us.
   ASSERT_EQ(0, tv2.tv_sec);
-  ASSERT_LT(tv2.tv_usec, 1000);
+  ASSERT_LT(tv2.tv_usec, 2000);
 }
@@ -63,7 +63,7 @@
   }
 
-  // Should be less than (a very generous, to try to avoid flakiness) 1000us.
+  // Should be less than (a very generous, to try to avoid flakiness) 2ms (2000us).
   ASSERT_EQ(0, tv2.tv_sec);